@@ -1,12 +1,12 @@
 from tqdm import *
 from time import sleep
-from random import randint
+from random import randint,choice
 from os import system
-
+from termcolor import colored
 import f61d.LOGO as LOGO
 
-print(LOGO.randlogo())
-print("Welcome to F61D")
+print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
+print(colored("Welcome to F61D. Use help() for help.",'green'))
 
 help_cont = {}
 help_cont[0] = 'help     : See this help page'
@@ -15,21 +15,22 @@ help_cont[2] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
 help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
-
+help_cont[6] = 'nim      : An interesting turtle game.'
 
 def help(page=1,lines = 5):
     maxPage = int((0.5+len(help_cont))/lines)+1
     if (page - 1) * lines >= len(help_cont):
-        aprint(f'Page Error, check the number : [{1},{maxPage}]')
+        print(f'Page Error, check the number : [{1},{maxPage}]')
         return
     print(f"{'=-'*14}= H E L P {'=-'*14}=\n")
     for i in range(lines):
         try:
             n = i+lines*(page-1)
-            print(f"   {n} - {help_cont[n]}")
+            ll = colored(f"{help_cont[n]}",'green')
+            print(f'   {n} - '+ll)
         except:break
     print(f"\n{'=-'*14} page({page}/{maxPage}) {'-='*14}")
-    if page < maxPage:print(f'\t\t\thelp({page+1}) for next page')
+    if page < maxPage:print(colored(f'\t\t\thelp({page+1}) for next page','green'))
 
 
 def fuckStar():
@@ -46,7 +47,7 @@ def fuckStar():
     for i in range(3):
         print('.',end='')
         sleep(0.4)
-    print('\n日卫星失败，请重新尝试')
+    print(colored('\n日卫星失败，请重新尝试','red'))
     
 def lifeGame():
     from f61d.lifeGame import game
@@ -80,7 +81,13 @@ please choose mode (1/2):
         df = b64encode(f)
     with open(f2,'wb') as ff:
         ff.write(df)
-    
+
+
+def nim():
+    import f61d.nim
+    nim()
+
+
 def prove(cont):
     '''
     Only the format is supported
@@ -117,6 +124,7 @@ def prove(cont):
     
 def main():
     help()
+    fuckStar()
     #r = prove('sha256(XXX + O3) = a289ace0c0301fba709365606da60acf11d793869a7c76083cef6c1ac6ff1396')
     #print(r)
 
